AshJido.Notifier (AshJido v1.0.0)

Copy Markdown View Source

Ash notifier that publishes Jido signals when configured resource actions complete.

Add this notifier to resource definitions to enable reactive publications:

use Ash.Resource,
  extensions: [AshJido],
  notifiers: [AshJido.Notifier]

jido do
  signal_bus MyApp.SignalBus
  publish :create, "my_app.resource.created"
end

Summary

Functions

Callback implementation for Ash.Notifier.load/2.

Functions

load(_, _)

Callback implementation for Ash.Notifier.load/2.