AshJido.SignalFactory (AshJido v1.0.0)

Copy Markdown View Source

Converts Ash notifier notifications into Jido.Signal structs.

Auto-derived signal types follow:

{prefix}.{resource_short_name}.{action_name}

Prefix resolution order:

  1. resource-level jido signal_prefix DSL option
  2. config :ash_jido, :signal_prefix
  3. default "ash"

Summary

Functions

Builds a Jido.Signal from an Ash notifier notification and signal configuration.

Types

reason()

@type reason() :: term()

Functions

from_notification(notification, publication)

@spec from_notification(Ash.Notifier.Notification.t(), AshJido.Publication.t()) ::
  {:ok, Jido.Signal.t()} | {:error, reason()}
@spec from_notification(Ash.Notifier.Notification.t(), map()) ::
  {:ok, Jido.Signal.t()} | {:error, reason()}

Builds a Jido.Signal from an Ash notifier notification and signal configuration.