Converts Ash notifier notifications into Jido.Signal structs.
Auto-derived signal types follow:
{prefix}.{resource_short_name}.{action_name}Prefix resolution order:
- resource-level
jido signal_prefixDSL option config :ash_jido, :signal_prefix- default
"ash"
Summary
Functions
Builds a Jido.Signal from an Ash notifier notification and signal configuration.
Types
@type reason() :: term()
Functions
@spec from_notification(Ash.Notifier.Notification.t(), AshJido.Publication.t()) :: {:ok, Jido.Signal.t()} | {:error, reason()}
@spec from_notification(Ash.Notifier.Notification.t(), map()) :: {:ok, Jido.Signal.t()} | {:error, reason()}
Builds a Jido.Signal from an Ash notifier notification and signal configuration.